@@ -1,4 +1,4 @@
 from __future__ import absolute_import
-from . import zhangbin_test1
+import zhangbin_test1
 
 name = 'zhangbin_test1'
\ No newline at end of file
